pub fn compile(pipeline: UserPipeline) -> Result<Pipeline, String>Expand description
“Compiles” the user-facing pipeline format into the explicit format the engine requires.
Errors
Returns an error if a node references a non-existent dependency in its needs field.